@@ -28,7 +28,9 @@ class FactorColumn : public Column {
     ~FactorColumn();
 
     double get_double() const {
-      return get_value();
+      int value = get_value();
+      if (value == NA_INTEGER) return NA_REAL;
+      return value;
     }
     int get_int() const {
       return get_value();
